# 多肽和蛋白的化学位移计算

** 这个项目的主要目的是辅助核磁谱图归属，特别是直接从系列可以预测结构，然后结构预测化学位移，归属HSQC谱图的指认 **

1. 以下这篇文章是说用QM来计算生物大分子的化学位移，Using quantum chemistry to estimate chemical shifts in biomolecules， 他们还开发一个[AFNMR](https://github.com/dacase/afnmr)软件来实现。我的想法是通过这个来计算多肽的化学位移，来辅助多肽的核磁谱图指认。当然如果计算运行的情况下，也是可以试试蛋白的计算。

2. 接下来一片比较新的预测蛋白化学位移的文献 Accurate prediction of chemical shifts for aqueous protein structure on “Real World” data。我没有搭建起来，可以试试。也提供的源码，https://github.com/THGLab/CSpred 目前好像是PDB格式问题，不知道，就是不给出结果。还得试试。

当然还有其他的预测软件，比如SPARTA+https://spin.niddk.nih.gov/bax/software/SPARTA+/， SHIFTX2， PROSHIFT，CamShift。

# 小分子化学位移计算


### 构象搜索

SDEGen: Learning to Evolve Molecular Conformations from Thermodynamic Noise for Conformation Generation https://pubs.rsc.org/en/content/articlelanding/2023/sc/d2sc04429c 采用随机微分方程模拟分子构象，联合概率深度学习的DDIM模型，提高效率和精度。可以用该模型和科音的molclus模型，还有XTB模型对比。我这边主要是要用来计算核磁化学位移的。https://github.com/HaotianZhangAI4Science/SDEGen 该文章提供源代码，可以后面试着用用。

- XTBDFT: Automated workflow for conformer searching of minima and transition states powered by extended tight binding and density functional theory https://github.com/sibo/xtbdft
- CREST https://github.com/grimme-lab/crest
- molclus http://www.keinsci.com/research/molclus.html


### 自动化计算核磁共振化学位移
- An automated framework for high-throughput predictions of NMR chemical shifts within liquid solutions 小分子的化学位移预测 
- Elucidating Structures of Complex Organic Compounds Using a Machine Learning Model Based on the 13C NMR Chemical Shifts 这一篇也不错，https://github.com/fenglb/SVM-M
- AI预测化学位移的方法：Transfer Learning from Simulation to Experimental Data: NMR Chemical Shift Predictions, CASCADE,Real-time prediction of 1H and 13C chemical shifts with DFT accuracy using a 3D graph neural network

### 量化自动化计算核磁共振全谱

https://github.com/grimme-lab/enso Fully Automated Quantum-Chemistry-Based Computation of Spin–Spin-Coupled Nuclear Magnetic Resonance Spectra

![](https://onlinelibrary.wiley.com/cms/asset/e2011bb9-a812-412f-8be0-d32635c47da8/anie201708266-fig-0006-m.png)


### 溶剂对化学位移的影响

NMR Chemical Shifts of Emerging Green Solvents, Acids, and Bases for Facile Trace Impurity Analysis https://pubs.acs.org/doi/10.1021/acssuschemeng.3c00244 本研究报道了42种绿色溶剂、酸和碱在8种NMR溶剂中的残余1H和13C NMR化学位移，即二甲基亚砜-d6、氯甲-d、D2O、CD3OD、CD3CN、丙酮-d6、四氢呋喃-8和甲苯-d8。本文还确定了1H信号的乘法和耦合常数。 https://nmrimpurities.pythonanywhere.com/ 

**我的考虑就是用量化计算（不同溶剂模型）这些化合物的氢谱和碳谱，然后拟合修正，看看是否经过溶剂拟合修正，可以得到更好的计算核磁数据。这是一个探索性的问题，值得做。
**


# 小分子耦合常数计算

### 预测耦合常数

- Prediction of spin–spin coupling constants with machine learning in NMR https://chemistry-europe.onlinelibrary.wiley.com/doi/full/10.1002/ansa.202000180 和 https://medium.com/@liztersahakyan/predicting-scalar-coupling-constants-using-machine-learning-c213af14e862 这个网站都是用ML预测小分子的耦合常数，都是使用https://www.kaggle.com/competitions/champs-scalar-coupling/leaderboard?tab=public 上面的数据集来做的预测。

kaggle有一个耦合常数预测的竞赛，The train dataset contained 4,658,147 scalar coupling observations of 85,003 unique molecules, and the test dataset contained 2,505,542 scalar coupling observations of 45,772 unique molecules。我也可以试试用这个来练练机器学习。

**我的想法，如果可以同时预测化学位移和耦合常数，那么我就可以对小分子进行全谱预测了。**

我的思路：先对分子进行构建，rdkit，然后进行构象寻找，可以用前面提到的方法，然后能量优化，找到能量最低的几个构象，进行boltzmann平均化处理。用这个平均化的作为描述符来预测。因为液体核磁的数据总体上是一个构象平均的结果。